-----------------------------------------------------------------------------------------------
-- Client Lua Script for SimpleSuitPower
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
require "GameLib"
require "Window"
require "Unit"

-------------------------------------------------------------------------------------
-- SimpleSuitPower Module Definition
-----------------------------------------------------------------------------------------------
local SimpleSuitPower = {} 

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function SimpleSuitPower:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function SimpleSuitPower:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"StalkerResource"}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- SimpleSuitPower OnLoad
-----------------------------------------------------------------------------------------------
function SimpleSuitPower:OnLoad()
	self:InitializeHooks()
end

function SimpleSuitPower:InitializeHooks()
	local crb = Apollo.GetAddon("StalkerResource")
	crb.OnFrame = self.OnFrame
end


function SimpleSuitPower:OnFrame(varName, cnt)
	if not self.wndResourceBar:IsValid() then
		return
	end
	
	local nLeft, nTop, nRight, nBottom = self.wndResourceBar:GetRect()
	Apollo.SetGlobalAnchor("CastingBarBottom", 0.0, nTop - 10, true)

	----------Resource 3
	local unitPlayer = GameLib.GetPlayerUnit()
	local nResourceCurrent = unitPlayer:GetResource(3)
	local nResourceMax = unitPlayer:GetMaxResource(3)
	local bInCombat = unitPlayer:IsInCombat()
	
	self.wndResourceBar:FindChild("CenterMeter1"):SetStyleEx("EdgeGlow", nResourceCurrent < nResourceMax)
	self.wndResourceBar:FindChild("CenterMeter1"):SetMax(nResourceMax)
	self.wndResourceBar:FindChild("CenterMeter1"):SetProgress(nResourceCurrent)
	self.wndResourceBar:FindChild("CenterMeter2"):SetStyleEx("EdgeGlow", nResourceCurrent < nResourceMax)
	self.wndResourceBar:FindChild("CenterMeter2"):SetMax(nResourceMax)
	self.wndResourceBar:FindChild("CenterMeter2"):SetProgress(nResourceCurrent)
	self.wndResourceBar:FindChild("CenterMeterText"):SetText(nResourceCurrent)
	self.wndResourceBar:FindChild("CenterMeterText"):Show(true)
	self.wndResourceBar:FindChild("CenterMeterText"):SetScale(1.2)
	self.wndResourceBar:FindChild("CenterMeterText"):SetAnchorOffsets(-200, -45.5, -140, -24.5)
	
	local wndBase = self.wndResourceBar:FindChild("Base")
	local wndInnate = self.wndResourceBar:FindChild("Innate")
	local strBaseWindow = ""
	local strInnateWindow = ""	
	
	wndBase:FindChild("Full"):Show(false)
	wndBase:FindChild("Innate"):Show(false)
	wndInnate:FindChild("Innate1"):SetOpacity(0.3)
	wndInnate:FindChild("Innate3"):SetOpacity(0.3)
	wndInnate:FindChild("Innate2"):SetOpacity(0.3)
	--wndInnate:FindChild("Innate4"):Show(true) -- Eyes sprite
	wndBase:FindChild("InCombat"):Show(false)
	wndBase:FindChild("OutOfCombat"):Show(false)
	
	if bInCombat then
		if nResourceCurrent == nResourceMax then
			strBaseWindow = "Full"
		else
			strBaseWindow = "Innate"
		end
	else
		strBaseWindow = "OutOfCombat"
	end
	
	if GameLib.IsCurrentInnateAbilityActive() then
		strInnateWindow = bInCombat and "InCombat" or "OutOfCombat"
	end
	
	if wndInnate:GetData() ~= strInnateWindow then
		wndInnate:FindChild("InCombat"):Show(false)
		wndInnate:FindChild("OutOfCombat"):Show(false)
		
		if strInnateWindow ~= "" then
			wndInnate:FindChild(strInnateWindow):Show(true)
		end
		
		wndInnate:SetData(bInnateWindow)
	end
	
	self.wndResourceBar:FindChild("Dot1"):Show(not bInCombat and nResourceCurrent == nResourceMax)
	--self.wndResourceBar:FindChild("Dot2"):Show(not bInCombat and nResourceCurrent == nResourceMax)
	self.wndResourceBar:FindChild("Dot3"):Show(bInCombat and nResourceCurrent == nResourceMax)
	--self.wndResourceBar:FindChild("Dot4"):Show(bInCombat and nResourceCurrent == nResourceMax)
	
	self.wndResourceBar:FindChild("CenterMeter1"):Show(nResourceCurrent < 36)
	self.wndResourceBar:FindChild("CenterMeter2"):Show(nResourceCurrent > 35)
	
	if wndBase:GetData() ~= strBaseWindow then
		self.wndResourceBar:FindChild("CenterMeterText"):SetTextColor(bInCombat and ApolloColor.new("xkcdLightblue") or ApolloColor.new("UI_TextHoloTitle"))
		
		wndBase:FindChild("Full"):Show(false)
		wndBase:FindChild("Innate"):Show(false)
		wndBase:FindChild("InCombat"):Show(false)
		wndBase:FindChild("OutOfCombat"):Show(false)
		
		wndBase:FindChild(strBaseWindow):Show(true, false, 0.3)
	
		wndBase:SetData(strBaseWindow)
	end
	
	--Toggle Visibility based on ui preference
	local unitPlayer = GameLib.GetPlayerUnit()
	local nVisibility = Apollo.GetConsoleVariable("hud.ResourceBarDisplay")
	
	if nVisibility == 2 then --always off
		self.wndResourceBar:Show(false)
	elseif nVisibility == 3 then --on in combat
		self.wndResourceBar:Show(bInCombat)	
	elseif nVisibility == 4 then --on out of combat
		self.wndResourceBar:Show(not bInCombat)
	else
		self.wndResourceBar:Show(true)
	end
end
-----------------------------------------------------------------------------------------------
-- SimpleSuitPower Instance
-----------------------------------------------------------------------------------------------
local SimpleSuitPowerInst = SimpleSuitPower:new()
SimpleSuitPowerInst:Init()
